@@ -1,5 +1,5 @@
 """`SQLAlchemy Faker <https://faker-sqlalchemy.readthedocs.io/en/latest/>`_ is a provider for the
-`Faker <https://github.com/joke2k/faker>`_ library that helps populate `SQLAlchemh ORM <https://www.sqlalchemy.org/>`_
+`Faker <https://github.com/joke2k/faker>`_ library that helps populate `SQLAlchemy ORM <https://www.sqlalchemy.org/>`_
 models with dummy data. Creating a new instance of a model can be as simple as calling
 ``fake.sqlalchemy_model(SomeModel)``.
 
@@ -52,50 +52,27 @@ from sqlalchemy import (
     inspect,
     Column,
     ARRAY,
-    BIGINT,
     BigInteger,
     BINARY,
-    BLOB,
-    BOOLEAN,
     Boolean,
-    CHAR,
     CLOB,
-    DATE,
     Date,
-    DATETIME,
     DateTime,
-    DECIMAL,
     Enum,
-    FLOAT,
     Float,
-    INT,
-    INTEGER,
     Integer,
     Interval,
     JSON,
     LargeBinary,
-    NCHAR,
-    NUMERIC,
     Numeric,
-    NVARCHAR,
-    PickleType,
-    REAL,
-    SMALLINT,
     SmallInteger,
     String,
-    TEXT,
-    TIME,
     Time,
-    TIMESTAMP,
-    TupleType,
-    TypeDecorator,
     Unicode,
     UnicodeText,
-    VARBINARY,
-    VARCHAR,
 )
 
-__version__ = "0.10.220807"
+__version__ = "0.10.220813"
 __all__ = (
     "SqlAlchemyProvider",
 )
@@ -146,7 +123,6 @@ DEFAULT_MAPPINGS: Dict[TypeEngine, GeneratorSpec] = {
     Numeric: "pyfloat",
     SmallInteger: "pyint",
     String: "pystr",
-    # Text: "pystr",
     Time: _generate_time,
     Unicode: "pystr",
     UnicodeText: "pystr",
